@@ -17,30 +17,20 @@
 # specific language governing permissions and limitations
 # under the License.
 
-from .running.test_runner import main
-from .running.HTMLTestRunner import SMTP
-from .running.config import Seldom
-from .testdata.parameterized import data, file_data, data_class
-from .webdriver import WebDriver
 from .case import TestCase
-from .driver import ChromeConfig
-from .driver import FirefoxConfig
-from .driver import IEConfig
-from .driver import EdgeConfig
-from .driver import OperaConfig
-from .driver import SafariConfig
-from .skip import skip
-from .skip import skip_if
-from .skip import skip_unless
-from .skip import depend
-from .skip import if_depend
-from .logging.log import _print
-from .logging.log import info
-from .logging.log import error
-from .logging.log import debug
+from .running.config import Seldom
+from .running.next_runner import main
+from .running.HTMLTestRunner import SMTP
+
+from .skip import *
+from .driver import *
+from .logging.log import *
+from .testdata.parameterization import *
+
+from .request import HttpRequest
 
 __author__ = "bugmaster"
 
-__version__ = "1.10.3"
+__version__ = "2.0.1"
 
-__description__ = "WebUI automation testing framework based on Selenium."
+__description__ = "WebUI/HTTP automation testing framework based on unittest."
