@@ -1,13 +1,20 @@
 import unittest
+import jmespath
 from time import sleep
+from jsonschema import validate
+from jsonschema.exceptions import ValidationError
 from selenium.webdriver import Chrome
+from selenium.webdriver.remote.webdriver import WebDriver as SeleniumWebDriver
 from seldom.webdriver import WebDriver
+from seldom.request import HttpRequest
 from seldom.running.config import Seldom
 from seldom.logging import log
 from seldom.logging.exceptions import NotFindElementError
+from seldom.utils import diff_json, AssertInfo
+from seldom.request import ResponseResult
 
 
-class TestCase(unittest.TestCase, WebDriver):
+class TestCase(unittest.TestCase, WebDriver, HttpRequest):
 
     def start_class(self):
         """
@@ -23,8 +30,6 @@ class TestCase(unittest.TestCase, WebDriver):
 
     @classmethod
     def setUpClass(cls):
-        if Seldom.driver is None:
-            Seldom.driver = Chrome()
         cls().start_class()
 
     @classmethod
@@ -54,7 +59,7 @@ class TestCase(unittest.TestCase, WebDriver):
         """
         browser driver
         """
-        if Seldom.driver is None:
+        if isinstance(Seldom.driver, SeleniumWebDriver) is False:
             Seldom.driver = Chrome()
         return Seldom.driver
 
@@ -69,15 +74,15 @@ class TestCase(unittest.TestCase, WebDriver):
             raise AssertionError("The assertion title cannot be empty.")
         for _ in range(Seldom.timeout):
             try:
-                self.assertEqual(title, self.get_title)
+                self.assertEqual(title, Seldom.driver.title)
                 log.info("👀 assert title: {title}.".format(
-                    title=self.get_title))
+                    title=Seldom.driver.title))
                 break
             except AssertionError:
                 sleep(1)
         else:
             log.warn("❌ assert fail: {title}.".format(title=title))
-            self.assertEqual(title, self.get_title, msg=msg)
+            self.assertEqual(title, Seldom.driver.title, msg=msg)
 
     def assertInTitle(self, title=None, msg=None):
         """
@@ -90,15 +95,15 @@ class TestCase(unittest.TestCase, WebDriver):
             raise AssertionError("The assertion title cannot be empty.")
         for _ in range(Seldom.timeout):
             try:
-                self.assertIn(title, self.get_title)
+                self.assertIn(title, Seldom.driver.title)
                 log.info("👀 assertIn title: {title}.".format(
-                    title=self.get_title))
+                    title=Seldom.driver.title))
                 break
             except AssertionError:
                 sleep(1)
         else:
             log.warn("❌ assertIn fail: {title}.".format(title=title))
-            self.assertIn(title, self.get_title, msg=msg)
+            self.assertIn(title, Seldom.driver.title, msg=msg)
 
     def assertUrl(self, url, msg=None):
         """
@@ -111,14 +116,14 @@ class TestCase(unittest.TestCase, WebDriver):
             raise AssertionError("The assertion URL cannot be empty.")
         for _ in range(Seldom.timeout):
             try:
-                self.assertEqual(url, self.get_url)
-                log.info("👀 assert url: {url}.".format(url=self.get_url))
+                self.assertEqual(url, Seldom.driver.current_url)
+                log.info("👀 assert url: {url}.".format(url=Seldom.driver.current_url))
                 break
             except AssertionError:
                 sleep(1)
         else:
             log.warn("❌ assert fail: {url}.".format(url=url))
-            self.assertEqual(url, self.get_url, msg=msg)
+            self.assertEqual(url, Seldom.driver.current_url, msg=msg)
 
     def assertInUrl(self, url=None, msg=None):
         """
@@ -131,14 +136,14 @@ class TestCase(unittest.TestCase, WebDriver):
             raise AssertionError("The assertion URL cannot be empty.")
         for _ in range(Seldom.timeout):
             try:
-                self.assertIn(url, self.get_url)
-                log.info("👀 assertIn url: {url}.".format(url=self.get_url))
+                self.assertIn(url, Seldom.driver.current_url)
+                log.info("👀 assertIn url: {url}.".format(url=Seldom.driver.current_url))
                 break
             except AssertionError:
                 sleep(1)
         else:
             log.warn("❌ assertIn fail: {url}.".format(url=url))
-            self.assertIn(url, self.get_url, msg=msg)
+            self.assertIn(url, Seldom.driver.current_url, msg=msg)
 
     def assertText(self, text=None, msg=None):
         """
@@ -171,7 +176,7 @@ class TestCase(unittest.TestCase, WebDriver):
         """
         if text is None:
             raise NameError("Alert text cannot be empty.")
-        alert_text = self.get_alert_text
+        alert_text = Seldom.driver.switch_to.alert.text
         self.assertEqual(alert_text, text, msg=msg)
 
     def assertElement(self, msg=None, **kwargs):
@@ -212,6 +217,46 @@ class TestCase(unittest.TestCase, WebDriver):
             else:
                 self.assertFalse(True, msg=msg)
 
+    def assertStatusCode(self, status_code, msg=None):
+        """
+        Asserts the HTTP status code
+        """
+        self.assertEqual(ResponseResult.status_code, status_code, msg=msg)
+
+    def assertSchema(self, schema):
+        """
+        Assert JSON Schema
+        doc: https://json-schema.org/
+        """
+        try:
+            validate(instance=ResponseResult.response, schema=schema)
+        except ValidationError as msg:
+            self.assertEqual("Response data", "Schema data", msg)
+        else:
+            self.assertTrue(True)
+
+    def assertJSON(self, assert_json):
+        """
+        Assert JSON data
+        """
+        AssertInfo.data = []
+        diff_json(ResponseResult.response, assert_json)
+        if len(AssertInfo.data) == 0:
+            self.assertTrue(True)
+        else:
+            self.assertEqual("Response data", "Assert data", msg=AssertInfo.data)
+
+    def assertPath(self, path, value):
+        """
+        Assert path data
+        doc: https://jmespath.org/
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        if search_value is None:
+            self.assertEqual(path, None, msg="{} No match".format(path))
+        else:
+            self.assertEqual(search_value, value)
+
     def xSkip(self, reason):
         """
         Skip this test.
