@@ -140,28 +140,24 @@ def create_scaffold(project_name):
 }
 
 '''
-    test_sample = '''import os
-import seldom
+    test_sample = '''import seldom
 from seldom import file_data
-CASE_DIR = os.path.dirname(os.path.abspath(__file__))
-# data file path
-YAML_FILE = os.path.join(CASE_DIR, "data.json")
 
 
 class SampleTest(seldom.TestCase):
 
     def test_case(self):
         """a simple test case """
-        self.get("http://www.itest.info")
+        self.open("http://www.itest.info")
         self.assertInUrl("itest.info")
 
 
-class BaiduTest(seldom.TestCase):
+class DDTTest(seldom.TestCase):
 
-    @file_data(file=YAML_FILE, key="baidu")
+    @file_data(file="data.json", key="baidu")
     def test_data_driver(self, _, keyword):
         """ data driver case """
-        self.get("https://www.baidu.com")
+        self.open("https://www.baidu.com")
         self.type(id_="kw", text=keyword)
         self.click(css="#su")
         self.assertInTitle(keyword)
@@ -175,15 +171,17 @@ if __name__ == '__main__':
 
 
 if __name__ == '__main__':
-    # run test
+    # run test file
+    # seldom.main("./test_dir/test_sample.py")
+    # run test dir
     seldom.main("./test_dir/")
-    #seldom.main("./test_dir/test_sample.py")
 
 """
     create_folder(project_name)
     create_folder(os.path.join(project_name, "test_dir"))
     create_folder(os.path.join(project_name, "reports"))
-    create_file(os.path.join(project_name, "test_dir", "data.json"), test_data)
+    create_folder(os.path.join(project_name, "test_data"))
+    create_file(os.path.join(project_name, "test_data", "data.json"), test_data)
     create_file(os.path.join(project_name, "test_dir", "test_sample.py"), test_sample)
     create_file(os.path.join(project_name, "run.py"), run_test)
 
@@ -221,7 +219,7 @@ def chrome(_os=None, os_bit=None):
     :param os_bit: system bit
     :return:
     """
-    latest_version = '89.0.4389.23'
+    latest_version = '91.0.4472.19'
     base_download = "https://cdn.npm.taobao.org/dist/chromedriver/%s/chromedriver_%s%s.zip"
     download = base_download % (latest_version, _os, os_bit)
     return 'chromedriver', download, latest_version
